
TODO: TODO_69_59_78_78: register known files as enum with metadata

It is easier to keep search where they are used via IDE.
Plus, it will provide common methods (like getting abs bath based on `argrelay_dir`).

